@@ -37,6 +37,16 @@ java_fail() {
     exit 1;
 }
 
+# Try to get the amount of memory available on the machine to come up
+# with a decent -Xmx argument, returned as the value of the
+# determined_xmx_arg (defaults in kilobytes, so you should add k
+# afterwards)
+determine_xmx_arg() {
+    # Yes, that's ugly, so what ??
+    mem=`free -k 2>/dev/null | head -n2 | tail -n1 | sed -r s/'[^0-9]+//' | cut -d' ' -f1`
+
+}
+
 # Try to find a Java runtime and set JAVA_HOME and JAVA_CMD accordingly.
 # If JAVA_CMD exists, nothing is done. If JAVA_HOME exists, only that
 # is searched.
@@ -178,11 +188,11 @@ locate_jar() {
     elif [ -r $jar ]; then
 	# Maybe issue a warning that jars should not be looked
 	# for absolutely ?
-	found_jar=$JAVA_JARPATH/$jar
+	found_jar=$jar
     elif [ -r $jar.jar ]; then
 	# Maybe issue a warning that jars should not be looked
 	# for absolutely ?
-	found_jar=$JAVA_JARPATH/$jar.jar
+	found_jar=$jar.jar
     else
 	return 1		# Not found
     fi
